@@ -5,7 +5,7 @@
 #' @param G an object of class \code{Matrix} representing the social network. Row and column names must be specified and match the order of the observations in \code{data}.
 #' @param model string. One of \code{c("model_A","model_B")}. See details.
 #' @param estimation string. One of \code{c("NLLS","MLE")}. They are used to implement respectively a non-linear least square and a Maximum Likelihood estimator.
-#' @param hypothesis string. One of \code{c("lim","het", "het_l", "het_r", "par")}. See details.
+#' @param hypothesis string. One of \code{c("lim","het", "het_l", "het_r", "par", "par_split_with", "par_split_btw", "par_split_with_btw")}. See details.
 #' @param endogeneity logical. Default is \code{FALSE}. If \code{TRUE}, \code{net_dep} implements a two-step correction procedure to control for the endogeneity of the network.
 #' @param correction Default is \code{NULL}. If \code{endogeneity = TRUE}, it is required to specify if the main regression should use an instrumental variable ("iv") or Heckman ("heckman") approach.
 #' @param first_step \ifelse{latex}{Default is NULL. If \code{endogeneity = TRUE}, it requires to specify one of \code{c("standard"}\cr\code{"fe", "shortest", "coauthors", "degree")}. See details.}{Default is NULL. If \code{endogeneity = TRUE}, it requires to specify one of \code{c("standard","fe", "shortest", "coauthors", "degree")}. See details.}
@@ -15,11 +15,12 @@
 #' @param start.val an optional list containing the starting values for the estimations. Object names must match the names provided in \code{formula}. It is also required to specify the value of both the constant and the decay parameter(s). See details.
 #' @param to_weight an optional vector of weights to be used in the fitting process to indicate that different observations have different variances. Should be \code{NULL} or a numeric vector. If non-\code{NULL}, it can be used to fit a weighted non-linear least squares (\code{estimation = "NLLS"}).
 #' @param time_fixed_effect an optional string. It indicates the name of the time index used in formula. It is used for models with longitudinal data.
+#' @param ind_fixed_effect an optional vector. Default is \code{NULL}. It indicates the name of the individual index contained in the data. If provided, individual fixed effects are automatically added to the \code{formula} of the main equation. If \code{endogeneity = TRUE}, the field \code{first_step} is overridden, and automatically set equal to \code{"fe"}. It is used for models with longitudinal data.
 #' @param mle_controls a list allowing the user to set upper and lower bounds for control variables in MLE estimation and the variance for the ML estimator. See details.
 #' @param kappa a normalization level with default equals 1.
 #' @return A list of three objects: i) Estimates of the main regression; ii) The vector of agents' parameter-dependent centrality; iii) Estimates of the first-step regression (if \code{endogeneity = TRUE})
 #' @details Agent's parameter-dependent centrality is obtained as a function of \itemize{
-#' \item the agent's characteristics and the performance of its socially connected peers, as in Battaglini, Leone Sciabolazza, Patacchini (2018), if \code{model = "model_B"};
+#' \item the agent's characteristics and the performance of its socially connected peers, as in Battaglini, Leone Sciabolazza, Patacchini (2020), if \code{model = "model_B"};
 #' \item \ifelse{latex}{the performance of its socially connected peers, as in Battaglini, Patacchini (2018), if \cr \code{model = "model_A"}.}{the performance of its socially connected peers, as in Battaglini, Patacchini (2018), if \code{model = "model_A"}.}
 #' }
 #' Peer effects are assumed to be homogenous if \code{hypothesis = "lim"}. They are assumed to be heterogenous by setting:\itemize{
@@ -27,9 +28,12 @@
 #' \item \code{hypothesis = "het_l"}, when peers' performance is susceptible to agent's characteristics and \code{model = "model_B"}.
 #' \item \code{hypothesis = "het_r"}, when agent's performance is susceptible to peers' characteristics and \code{model = "model_B"}.
 #' \item \code{hypothesis = "par"}, when \code{model = "model_B"}, if the network is formed by interactions between and within two different groups.
+#' \item \code{hypothesis = "par_split_with"}, when \code{model = "model_B"}, if the network is formed by interactions between and within two different groups, and interactions within each group are different from the other.
+#' \item \code{hypothesis = "par_split_btw"}, when \code{model = "model_B"}, if the network is formed by interactions between and within two different groups, and interactions between groups are different according to their direction.
+#' \item \code{hypothesis = "par_split_with_btw"}, when \code{model = "model_B"}, if the network is formed by interactions between and within two different groups, interactions within each group are different from the other, and interactions between groups are different according to their direction.
 #' }
 #' When \code{hypothesis} is equal to \code{"het"}, \code{"het_l"}, or \code{"het_r"}, the argument \code{z} is used to specify the source of heterogeneity: i.e. the attribute affecting the ability of the agent to influence or be influenced by peers.
-#' When \code{hypothesis} is equal to \code{"par"}, the argument \code{"z"} is used to partition observations in two groups: e.g. the generic element \emph{i} of vector \code{z} takes the value 1 if agent \emph{i} is member of the first group, and it takes 2 otherwise. \cr
+#' When \code{hypothesis} is equal to \code{"par"}, \code{"par_split_with"}, \code{"par_split_btw"}, or \code{"par_split_with_btw"} the argument \code{"z"} is used to partition observations in two groups: e.g. the generic element \emph{i} of vector \code{z} takes the value 1 if agent \emph{i} is member of the first group, and it takes 2 otherwise. \cr
 #' \cr
 #' If \code{endogeneity = TRUE}, a two-step estimation is implemented to control for network endogeneity. The argument \code{first_step} is used to control for the specification of the first-step model, e.g.:
 #' \itemize{
@@ -46,16 +50,19 @@
 #' \item \code{"theta_0","theta_1"}, if \code{hypothesis="het_l"}
 #' \item \code{"eta_0","eta_1"}, if \code{hypothesis="het_r"}
 #' \item \code{"phi_within","phi_between"}, if \code{hypothesis="par"}
+#' \item \code{"phi_within_0","phi_within_1","phi_between"}, if \code{hypothesis="par_split_with"}
+#' \item \code{"phi_within","phi_between_0","phi_between_1"}, if \code{hypothesis="par_split_btw"}
+#' \item \code{"phi_within_0","phi_within_1","phi_between_0","phi_between_1"}, if \code{hypothesis="par_split_with_btw"}
 #' }
 #' The interaction term when \code{hypothesis="het"} must be labelled  \code{"gamma"}. The label to be used for unobservables when \code{endogeneity = TRUE} is \code{"unobservables"}. When \code{estimation = "MLE"}, it is required to set also the starting value for the variance of the ML estimator. This should be labelled as "sigma". \cr
 #' The argument \code{mle_controls} takes a list of two objects. The first is a named numeric vector used to set upper and lower bounds for control variables. The second object is a vector used to set upper (first value) and lower (second value) bounds for the variance of the Maximum Likelihood estimator.\cr
 #' Names in \code{mle_controls} must be equal to those used in \code{start.val}.
 #' For additional details, see the vignette.
 #' @references
-#' Battaglini M., E. Patacchini (2018), "Influencing Connected Legislators",  Journal of Political Economy, forthcoming. \cr
-#' Battaglini M., V. Leone Sciabolazza, E. Patacchini (2018), "Effectiveness of Connected Legislators",  NBER, 24442. \cr
-#' Battaglini M., V. Leone Sciabolazza, E. Patacchini, S. Peng (2018), "Econet: An R package for the Estimation of parameter-dependent centrality measures", NBER Working Paper (24442). \cr
-#' Fafchamps, M., M. J. Leij and S. Goyal (2010), “Matching and network effects”, Journal of the European Economic Association, 8(1): 203-231. \cr
+#' Battaglini M., E. Patacchini (2018), "Influencing Connected Legislators," Journal of Political Economy, 126(6): 2277-2322. \cr
+#' Battaglini M., V. Leone Sciabolazza, E. Patacchini (2020), "Effectiveness of Connected Legislators,"  American Journal of Political Science, forthcoming. \cr
+#' Battaglini M., V. Leone Sciabolazza, E. Patacchini, S. Peng (2020), "Econet: An R package for the Estimation of parameter-dependent centrality measures", Mimeo. \cr
+#' Fafchamps, M., M. J. Leij and S. Goyal (2010), “Matching and network effects,” Journal of the European Economic Association, 8(1): 203-231. \cr
 #' Graham B. (2015), “Methods of identification in social networks,” Annual Review of Economics, 7, 465 - 485. \cr
 #' Graham B. (2017), “An econometric model of network formation with degree heterogeneity,” Econometrica 85 (4), 1033 - 1063. \cr
 #' @examples
@@ -127,7 +134,7 @@
 #' db_model_B[are_factors] <- lapply(db_model_B[are_factors], factor)
 #'
 #' # Specify formula
-#' f_model_B <- formula("les ~gender + party + nchair")
+#' f_model_B <- formula("les ~ gender + party + nchair")
 #'
 #' # Specify starting values
 #' starting <- c(alpha = 0.23952,
@@ -211,8 +218,8 @@
 #'                          z = z, start.val = starting)
 #'
 #' # Store and print results
-#' summary(party_estimate_model_B)
-#' party_estimate_model_B$centrality
+#' summary(party_model_B)
+#' party_model_B$centrality
 #' }
 #' # WARNING, This toy example is provided only for runtime execution.
 #' # Please refer to previous examples for sensible calculations.
@@ -246,6 +253,7 @@ net_dep <- function(formula = formula(),
                     start.val = NULL,
                     to_weight = NULL,
                     time_fixed_effect = NULL,
+                    ind_fixed_effect = NULL,
                     mle_controls = NULL,
                     kappa = NULL) {
 
@@ -285,6 +293,10 @@ net_dep <- function(formula = formula(),
     first_step <- "standard"
   }
 
+  if (endogeneity == TRUE & !is.null(ind_fixed_effect)) {
+    first_step <- "fe"
+  }
+
   if (endogeneity) {
 
     if (!is.null(data_first_step)) {
@@ -352,7 +364,23 @@ net_dep <- function(formula = formula(),
     }
   }
 
-  if (!is.null(z) & hypothesis != "par") {
+  if (!is.null(ind_fixed_effect)) {
+    individual_fixed_effect <- as.factor(data[, ind_fixed_effect])
+    mm <- model.matrix(~individual_fixed_effect - 1, model.frame(~individual_fixed_effect - 1))
+    mm <- matrix(mm, nrow(mm), ncol(mm))
+    colnames(mm) <- levels(individual_fixed_effect)
+    mm <- mm[, -1]
+    if (is.null(start.val)) {
+      start_val_mm <- setNames(rep(0.01, ncol(mm)), colnames(mm))
+      start_val_mm <- toList(start_val_mm)
+      starting.values <- c(starting.values, start_val_mm)
+    }
+    mm_df <- data.frame(mm)
+    e <- c(e, as.list(mm_df))
+    X <- cbind(X, mm_df)
+  }
+
+  if (!is.null(z) & hypothesis != "par" & hypothesis != "par_split_btw" & hypothesis != "par_split_with" & hypothesis != "par_split_with_btw") {
     check_z <- Reduce("+", lapply(X, identical, z))
     if (check_z == 0) {
       X <- cbind(X, z)
@@ -442,6 +470,28 @@ net_dep <- function(formula = formula(),
                                  G_between = e[["G_between"]],
                                  starting.values = starting.values,
                                  boundL = boundL, boundU = boundU)
+      } else if (hypothesis == "par_split_with") {
+        second_step <- mle_party_split_with(y = y, X = X,
+                                            G_within_0 = e[["G_within_0"]],
+                                            G_within_1 = e[["G_within_1"]],
+                                            G_between = e[["G_between"]],
+                                            starting.values = starting.values,
+                                            boundL = boundL, boundU = boundU)
+      } else if (hypothesis == "par_split_btw") {
+        second_step <- mle_party_split_btw(y = y, X = X,
+                                           G_within = e[["G_within"]],
+                                           G_between_01 = e[["G_between_01"]],
+                                           G_between_10 = e[["G_between_10"]],
+                                           starting.values = starting.values,
+                                           boundL = boundL, boundU = boundU)
+      } else if (hypothesis == "par_split_with_btw") {
+        second_step <- mle_party_split_with_btw(y = y, X = X,
+                                                G_within_0 = e[["G_within_0"]],
+                                                G_within_1 = e[["G_within_1"]],
+                                                G_between_01 = e[["G_between_01"]],
+                                                G_between_10 = e[["G_between_10"]],
+                                                starting.values = starting.values,
+                                                boundL = boundL, boundU = boundU)
       }
     }
 
